% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lmDynamic.R
\name{lmDynamic}
\alias{lmDynamic}
\title{Combine regressions based on point information criteria}
\usage{
lmDynamic(data, ic = c("AICc", "AIC", "BIC", "BICc"), bruteForce = FALSE,
  silent = TRUE)
}
\arguments{
\item{data}{Data frame containing dependent variable in the first column and
the others in the rest.}

\item{ic}{Information criterion to use.}

\item{bruteForce}{If \code{TRUE}, then all the possible models are generated
and combined. Otherwise the best model is found and then models around that
one are produced and then combined.}

\item{silent}{If \code{FALSE}, then nothing is silent, everything is printed
out. \code{TRUE} means that nothing is produced.}
}
\value{
Function returns \code{model} - the final model of the class
"lm.combined", which includes time varying parameters and dynamic importance
of each variable.
}
\description{
Function combines parameters of linear regressions of the first variable
on all the other provided data using pAIC weights
}
\details{
The algorithm uses lm() to fit different models and then combines the models
based on the selected point IC. This is a dynamic counterpart of
\link[greybox]{lmCombine} function.
}
\examples{

### Simple example
xreg <- cbind(rnorm(100,10,3),rnorm(100,50,5))
xreg <- cbind(100+0.5*xreg[,1]-0.75*xreg[,2]+rnorm(100,0,3),xreg,rnorm(100,300,10))
colnames(xreg) <- c("y","x1","x2","Noise")
inSample <- xreg[1:80,]
outSample <- xreg[-c(1:80),]
# Combine all the possible models
ourModel <- lmDynamic(inSample,bruteForce=TRUE)
forecast(ourModel,outSample)
plot(forecast(ourModel,outSample))

}
\references{
\itemize{
\item Burnham Kenneth P. and Anderson David R. (2002). Model Selection
and Multimodel Inference. A Practical Information-Theoretic Approach.
Springer-Verlag New York. DOI: [10.1007/b97636](http://dx.doi.org/10.1007/b97636).
}
}
\seealso{
\code{\link[greybox]{stepwise}, \link[greybox]{lmCombine}}
}
\author{
Ivan Svetunkov, \email{ivan@svetunkov.ru}
}
\keyword{models}
\keyword{nonlinear}
\keyword{regression}
\keyword{ts}
